==> bobwarfare_0.15.1.zip: bobwarfare_0.15.1/prototypes/item/parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "petroleum-jelly",
    icon = "__bobwarfare__/graphics/icons/petroleum-jelly.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[petroleum-jelly]",
    stack_size = 100
  },

  {
    type = "item",
    name = "gun-cotton",
    icon = "__bobwarfare__/graphics/icons/gun-cotton.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-resource",
    order = "f[gun-cotton]",
    stack_size = 100
  },

  {
    type = "item",
    name = "cordite",
    icon = "__bobwarfare__/graphics/icons/cordite.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[cordite]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-casing",
    icon = "__bobwarfare__/graphics/icons/bullet-casing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "magazine",
    icon = "__bobwarfare__/graphics/icons/magazine.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[magazine]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile]",
    stack_size = 100
  },

  {
    type = "item",
    name = "bullet",
    icon = "__bobwarfare__/graphics/icons/bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet]",
    stack_size = 100
  },


  {
    type = "item",
    name = "ap-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/ap-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "ap-bullet",
    icon = "__bobwarfare__/graphics/icons/ap-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/he-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-he]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet",
    icon = "__bobwarfare__/graphics/icons/he-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-he]",
    stack_size = 100
  },


  {
    type = "item",
    name = "flame-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/flame-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-flame]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-bullet",
    icon = "__bobwarfare__/graphics/icons/flame-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-flame]",
    stack_size = 100
  },


  {
    type = "item",
    name = "acid-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/acid-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-acid]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-bullet",
    icon = "__bobwarfare__/graphics/icons/acid-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-acid]",
    stack_size = 100
  },


  {
    type = "item",
    name = "poison-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/poison-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-poison]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-bullet",
    icon = "__bobwarfare__/graphics/icons/poison-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-poison]",
    stack_size = 100
  },


  {
    type = "item",
    name = "electric-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/electric-bullet-projectile.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-electric]",
    stack_size = 100
  },

  {
    type = "item",
    name = "electric-bullet",
    icon = "__bobwarfare__/graphics/icons/electric-bullet.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[bullet-electric]",
    stack_size = 100
  },


  {
    type = "item",
    name = "shotgun-shell-casing",
    icon = "__bobwarfare__/graphics/icons/shotgun-shell-casing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[shotgun-shell-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "shot",
    icon = "__bobwarfare__/graphics/icons/shot.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[shot]",
    stack_size = 500
  },


  {
    type = "item",
    name = "laser-rifle-battery-case",
    icon = "__bobwarfare__/graphics/icons/laser-rifle-battery-case.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[laser-rifle-battery-case]",
    stack_size = 100
  },


  {
    type = "item",
    name = "rocket-engine",
    icon = "__bobwarfare__/graphics/icons/rocket-engine.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f[rocket-engine]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-body",
    icon = "__bobwarfare__/graphics/icons/rocket-body.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[rocket-body]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "piercing-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-pierce.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[piercing-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "electric-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-electric.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[electric-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "explosive-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-explosive.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[explosive-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-acid.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[acid-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-fire.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[flame-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-poison.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-ammo-parts",
    order = "f[poison-rocket-warhead]",
    stack_size = 100
  },
}
)

==> bobwarfare_1.1.2.zip: bobwarfare_1.1.2/prototypes/item/parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "petroleum-jelly",
    icon = "__bobwarfare__/graphics/icons/petroleum-jelly.png",
    icon_size = 32,
    subgroup = "bob-resource",
    order = "f[petroleum-jelly]",
    stack_size = 100
  },

  {
    type = "item",
    name = "gun-cotton",
    icon = "__bobwarfare__/graphics/icons/gun-cotton.png",
    icon_size = 32,
    subgroup = "bob-resource",
    order = "f[gun-cotton]",
    stack_size = 100
  },

  {
    type = "item",
    name = "cordite",
    icon = "__bobwarfare__/graphics/icons/cordite.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[cordite]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-casing",
    icon = "__bobwarfare__/graphics/icons/bullet-casing.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "magazine",
    icon = "__bobwarfare__/graphics/icons/magazine.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[magazine]",
    stack_size = 100
  },


  {
    type = "item",
    name = "bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile]",
    stack_size = 100
  },

  {
    type = "item",
    name = "bullet",
    icon = "__bobwarfare__/graphics/icons/bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet]",
    stack_size = 100
  },


  {
    type = "item",
    name = "ap-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/ap-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "ap-bullet",
    icon = "__bobwarfare__/graphics/icons/ap-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-ap]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/he-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-he]",
    stack_size = 100
  },

  {
    type = "item",
    name = "he-bullet",
    icon = "__bobwarfare__/graphics/icons/he-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-he]",
    stack_size = 100
  },


  {
    type = "item",
    name = "flame-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/flame-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-flame]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-bullet",
    icon = "__bobwarfare__/graphics/icons/flame-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-flame]",
    stack_size = 100
  },


  {
    type = "item",
    name = "acid-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/acid-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-acid]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-bullet",
    icon = "__bobwarfare__/graphics/icons/acid-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-acid]",
    stack_size = 100
  },


  {
    type = "item",
    name = "poison-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/poison-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-poison]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-bullet",
    icon = "__bobwarfare__/graphics/icons/poison-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-poison]",
    stack_size = 100
  },


  {
    type = "item",
    name = "electric-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/electric-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-electric]",
    stack_size = 100
  },

  {
    type = "item",
    name = "electric-bullet",
    icon = "__bobwarfare__/graphics/icons/electric-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-electric]",
    stack_size = 100
  },


  {
    type = "item",
    name = "uranium-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/uranium-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-uranium]",
    stack_size = 100
  },

  {
    type = "item",
    name = "uranium-bullet",
    icon = "__bobwarfare__/graphics/icons/uranium-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-uranium]",
    stack_size = 100
  },


  {
    type = "item",
    name = "shotgun-shell-casing",
    icon = "__bobwarfare__/graphics/icons/shotgun-shell-casing.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[shotgun-shell-casing]",
    stack_size = 100
  },

  {
    type = "item",
    name = "shot",
    icon = "__bobwarfare__/graphics/icons/shot.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[shot]",
    stack_size = 500
  },


  {
    type = "item",
    name = "laser-rifle-battery-case",
    icon = "__bobwarfare__/graphics/icons/laser-rifle-battery-case.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[laser-rifle-battery-case]",
    stack_size = 100
  },


  {
    type = "item",
    name = "rocket-engine",
    icon = "__bobwarfare__/graphics/icons/rocket-engine.png",
    icon_size = 32,
    subgroup = "bob-intermediates",
    order = "f[rocket-engine]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-body",
    icon = "__bobwarfare__/graphics/icons/rocket-body.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[rocket-body]",
    stack_size = 100
  },

  {
    type = "item",
    name = "rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "piercing-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-pierce.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[piercing-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "electric-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-electric.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[electric-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "explosive-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-explosive.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[explosive-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "acid-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-acid.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[acid-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "flame-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-fire.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[flame-rocket-warhead]",
    stack_size = 100
  },

  {
    type = "item",
    name = "poison-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-poison.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[poison-rocket-warhead]",
    stack_size = 100
  },
}
)


data:extend(
{
  {
    type = "item",
    name = "plasma-bullet-projectile",
    icon = "__bobwarfare__/graphics/icons/plasma-bullet-projectile.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-projectile-plasma]",
    stack_size = 100
  },

  {
    type = "item",
    name = "plasma-bullet",
    icon = "__bobwarfare__/graphics/icons/plasma-bullet.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[bullet-plasma]",
    stack_size = 100
  },

  {
    type = "item",
    name = "plasma-rocket-warhead",
    icon = "__bobwarfare__/graphics/icons/missile-warhead-plasma.png",
    icon_size = 32,
    subgroup = "bob-ammo-parts",
    order = "f[plasma-rocket-warhead]",
    stack_size = 100
  },
}
)
